import React from 'react';
import { IReactCodemirror } from '@uiw/react-codemirror';
import { CodeSandboxProps } from '@uiw/react-codesandbox';
import { CodepenProps } from '@uiw/react-codepen';
import { SplitProps } from '@uiw/react-split';
import './monokai.css';
import './index.less';
export interface CodePreviewProps extends SplitProps {
    prefixCls?: string;
    style?: React.CSSProperties;
    /**
     * To specify a CSS class, use the className attribute.
     */
    className?: string;
    /**
     * string|object. The mode to use. When not given, this will default to the first mode that was loaded.
     * It may be a string, which either simply names the mode or is a MIME type associated with the mode.
     * Alternatively, it may be an object containing configuration options for the mode,
     * with a name property that names the mode (for example `{name: "javascript", json: true}` ).
     */
    language?: string | {
        name: string;
        json: boolean;
    };
    /**
     * Whether to display the border.
     */
    bordered?: boolean;
    /**
     * `JSX` source code
     */
    code?: string;
    /**
     * Whether to display the code interface.
     */
    noCode?: boolean;
    /**
     * Is the background white or plaid?
     */
    bgWhite?: boolean;
    /**
     * Only show Edit
     */
    onlyEdit?: boolean;
    /**
     * Whether to display the preview interface.
     */
    noPreview?: boolean;
    /**
     * Preview area does not display scroll bars
     */
    noScroll?: boolean;
    /**
     * Modify ReactCodemirror props.
     */
    editProps?: IReactCodemirror;
    /**
     * Dependent component
     */
    dependencies?: Record<string, any>;
    codePenOption?: CodepenProps & {
        /**
         * Packages that do not require comments.
         * @example ['uiw']
         */
        includeModule?: string[];
    };
    codeSandboxOption?: CodeSandboxProps;
    /** @default 'Code' */
    btnText?: string;
    /** @default 'Hide Editor' */
    btnHideText?: string;
}
export interface ICodePreviewState {
    errorMessage: string;
    fullScreen: boolean;
    width: number | string;
    copied: boolean;
    showEdit: boolean;
}
export default class CodePreview extends React.PureComponent<CodePreviewProps, ICodePreviewState> {
    demoDom: React.RefObject<HTMLDivElement>;
    editor: React.RefObject<any>;
    language: string;
    initHeight: number;
    playerId: string;
    static defaultProps: CodePreviewProps;
    state: ICodePreviewState;
    componentDidMount(): void;
    componentDidUpdate(prevProps: CodePreviewProps): void;
    executeCode(codeStr: string): Promise<void>;
    /**
     * onCopyCode
     */
    onCopyCode(): void;
    /**
     * onFullScreen
     */
    onFullScreen(): void;
    initOldHeight(): void;
    /**
     * onSwitchSource
     */
    onSwitchSource(): void;
    render(): JSX.Element;
}
